@@ -1,5 +1,6 @@
 from yearmaps.providers.BBDCProvider import BBDCProvider
+from yearmaps.providers.BilibiliProvider import BilibiliProvider
 from yearmaps.providers.CodeforcesProvider import CodeforcesProvider
 from yearmaps.providers.GitHubProvider import GitHubProvider
 
-providers = [BBDCProvider, GitHubProvider, CodeforcesProvider]
+providers = [BBDCProvider, BilibiliProvider, CodeforcesProvider, GitHubProvider]
